@@ -64,6 +64,7 @@ def get_radial_potential(a, xc, D_sp):
     fh_g = -np.array([np.sum(rho_g[:ig]) for ig in range(len(r_g))]) / r_g**2
 
     f_g = fc_g + fh_g
+
     # xc force
     if xc.name != 'GLLBSC':
         v_sg = np.zeros_like(n_sg)
@@ -287,6 +288,8 @@ def get_anisotropy(calc, theta=0.0, phi=0.0, nbands=None, width=None):
     relative to the sum of eigenvalues without spinorbit coupling"""
 
     Ns = calc.wfs.nspins
+    noncollinear = not calc.density.collinear
+
     e_skn = np.array([[calc.get_eigenvalues(kpt=k, spin=s)
                        for k in range(len(calc.get_ibz_k_points()))]
                       for s in range(Ns)])
@@ -301,6 +304,9 @@ def get_anisotropy(calc, theta=0.0, phi=0.0, nbands=None, width=None):
     f_kn = np.reshape(np.swapaxes(f_skn, 0, 1), (len(f_skn[0]),
                                                  Ns * len(f_skn[0, 0])))
     f_kn = np.sort(f_kn, 1)[:, ::-1]
+    if noncollinear:
+        f_kn *= 2
+
     E = np.sum(e_kn * f_kn)
 
     from gpaw.occupations import occupation_numbers
@@ -320,10 +326,58 @@ def get_anisotropy(calc, theta=0.0, phi=0.0, nbands=None, width=None):
     return E_so - E
 
 
+def get_spinorbit_projections(calc, ik, v_nm):
+    # For spinors the number of projectors and bands are doubled
+    Na = len(calc.atoms)
+    Nk = len(calc.get_ibz_k_points())
+    Ns = calc.wfs.nspins
+
+    v0_mn = v_nm[::2].T
+    v1_mn = v_nm[1::2].T
+        
+    P_ani = {}
+    for ia in range(Na):
+        P0_ni = calc.wfs.kpt_u[ik].P_ani[ia]
+        P1_ni = calc.wfs.kpt_u[(Ns - 1) * Nk + ik].P_ani[ia]
+
+        P0_mi = np.dot(v0_mn, P0_ni)
+        P1_mi = np.dot(v1_mn, P1_ni)
+        P_mi = np.zeros((len(P0_mi), 2 * len(P0_mi[0])), complex)
+        P_mi[:, ::2] = P0_mi
+        P_mi[:, 1::2] = P1_mi
+        P_ani[ia] = P_mi
+
+    return P_ani
+
+    
+def get_spinorbit_wavefunctions(calc, ik, v_nm):
+    # For spinors the number of bands is doubled and a spin dimension is added
+    Ns = calc.wfs.nspins
+    Nn = calc.wfs.bd.nbands
+
+    v0_mn = v_nm[::2].T
+    v1_mn = v_nm[1::2].T
+    
+    u0_nG = np.array([calc.wfs.get_wave_function_array(n, ik, 0)
+                      for n in range(Nn)])
+    u1_nG = np.array([calc.wfs.get_wave_function_array(n, ik, (Ns - 1))
+                      for n in range(Nn)])
+    u0_mG = np.swapaxes(np.dot(v0_mn, np.swapaxes(u0_nG, 0, 2)), 1, 2)
+    u1_mG = np.swapaxes(np.dot(v1_mn, np.swapaxes(u1_nG, 0, 2)), 1, 2)
+    u_mG = np.zeros((len(u0_mG),
+                     2,
+                     len(u0_mG[0]),
+                     len(u0_mG[0, 0]),
+                     len(u0_mG[0, 0, 0])), complex)
+    u_mG[:, 0] = u0_mG
+    u_mG[:, 1] = u1_mG
+
+    return u_mG
+
+    
 def get_magnetic_moments(calc, theta=0.0, phi=0.0, nbands=None, width=None):
     """Calculates the magnetic moments inside all PAW spheres"""
 
-    from gpaw.wannier90 import get_spinorbit_projections
     from gpaw.utilities import unpack
 
     if nbands is None:
@@ -392,9 +446,7 @@ def get_magnetic_moments(calc, theta=0.0, phi=0.0, nbands=None, width=None):
         Delta_p = calc.density.setups[a].Delta_pL[:, 0].copy()
         Delta_ij = unpack(Delta_p)
         for ik in range(Nk):
-            P_ami = get_spinorbit_projections(calc, ik, v_knm[ik],
-                                              nbands=nbands)
-
+            P_ami = get_spinorbit_projections(calc, ik, v_knm[ik])
             P_smi = np.array([P_ami[a][:, ::2], P_ami[a][:, 1::2]])
             P_smi = np.dot(C_ss, np.swapaxes(P_smi, 0, 1))
 
